=================
chibi_marshmallow
=================


.. image:: https://img.shields.io/pypi/v/chibi_marshmallow.svg
        :target: https://pypi.python.org/pypi/chibi_marshmallow

.. image:: https://img.shields.io/travis/dem4ply/chibi_marshmallow.svg
        :target: https://travis-ci.org/dem4ply/chibi_marshmallow

.. image:: https://readthedocs.org/projects/chibi-marshmallow/badge/?version=latest
        :target: https://chibi-marshmallow.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




fields and snippets for marshmallow


* Free software: WTFPL
* Documentation: https://chibi-marshmallow.readthedocs.io.


Features
--------

* TODO
